import matplotlib.pyplot as p
import numpy as np

def pie(list,colors=None,labels=None,font=None,title=None):
    list=np.array(list)
    p.rcParams['font.sans-serif']=[font]
    if colors==None:
        p.pie(list,labels)
        p.title(title)
        p.show()
    else:
        p.pie(a,colers=colers,labels=labels)
        p.title(title)
        p.show()

def plot(txtpath,font=None,labels=None,title=None):
    a=np.loadtxt(txtpath)
    p.rcParams['font.sans-serif']=[font]
    p.plot(a)
    p.legend(labels)
    p.title(title)
    p.show()

def bar(xnum,ynum,width=0.5,font=None,xlabel=None,ylabel=None,title=None):
    p.rcParams['font.sans-serif']=[font]
    p.bar(xnum,ynum,width=width)
    p.xlabel(xlabel)
    p.ylabel(ylabel)
    p.title(title)
    p.show()



def get_version():
    '''
    import os
    from pathlib import Path
    txt="I:\sky\py11\Lib\site-packages\txtplan\version.mx"
    extension = Path(txt).suffix
    filename=os.path.split(txt)
    fiesion=os.path.splitext(extension)
    newname="version.txt"
    os.rename(txt,newname)
    with open(newname,"r") as r:
        version=r.read()
    txt="I:\sky\py11\Lib\site-packages\txtplan\version.txt"
    extension = Path(txt).suffix
    filename=os.path.split(txt)
    fiesion=os.path.splitext(extension)
    newname="version.mx"
    os.rename(txt,newname)
    return version
    '''
    with open("I:/sky/py11/Lib/site-packages/txtplan/version.txt","r") as r:
        version=r.read()
    return version



import numpy as np

class save_txt():
    def __init__(self,x,y):
        pass
    def save_zeros(self,path_and_name,times=5):
        try:
            times=int(times)
        except ValueError:
            print("Times must be int.")
        list=np.zeros(times)
        list=np.array(list)
        np.savetxt(path_and_name,list,fmt='%')
        del list
    def save_ones(self,path_and_name,times=5):
        try:
            times=int(times)
        except ValueError:
            print("Times must be int.")
        list=np.ones(times)
        list=np.array(list)
        np.savetxt(path_and_name,list,fmt='%')
        del list
    def save_youwant(self,path_and_name,times=5,num=2):
        try:
            times=int(times)
        except ValueError:
            print("Times must be int.")
        list=[]
        a=0
        while a<5:
            list.append(num)
            a+=1
        list=np.array(list)
        np.savetxt(path_and_name,list,fmt='%')
        del list,a
    def makeForminTxt(self,list,path_and_name,shape,fmt='%.2f',delim='/t'):
        try:
            shape=list(shape)
            if len(shape)==2:
                x=shape[0]
                y=shape[1]
                list=np.shape(x,y)
                np.savetxt(path_and_name,list,fmt=fmt,delimiter=delim)
            else:
                print("shape's must be 2")
        except:
            print("shape must be list")



#from .txt import (txt,numbers_in_txt)
from .version import get_version

if get_version()=='1.0.2':
    pass
else:
    print("Please improve this model in to 1.0.2.")
    pass

__all__=['txt','plot']



try:
    import numpy as np
    import matplotlib as mt
except ImportError:
    print("Please install numpy and matplotlib.")
except ModuleNotFoundError:
    print("Please install numpy and matplotlib.")

'''
THE FIRST ONE IS ABOUT TXT WRITE AND READ.
'''
class txt():
    def __init__(self,path,ways="w+"):
        if ways==("r" or "r+"):
            try:
                a=open(path,ways)
            except:
                raise FileNotFoundError(f"Can not found txt",path)
        elif ways==("a" or "a+"):
            print("This will delete the words in the txt.")
        a=open(path,ways)
        a.close()
        
    def __new__(self):
        pass
    
    def write_oneline(self,txt):
        with open(path,"w+") as f:
            f.write(txt)
            f.close

    def read_oneline(self):
        with open(path,"w+") as f:
            txt=f.readline()
            f.close()
            return txt

    def read_all_notlist(self):
        with open(path,"w+") as f:
            txt=f.read()
            f.close()
            return txt

    def read_all_inlist(self):
        with open(path,"w+") as f:
            txt=f.readlines()
            f.close()
            return txt

def numbers_in_txt(path,stop,start=0,step=1,numbertipe='%.3f'):
    if stop<start:
        def unrange(stop,start,step):
            list=[]
            while stop>=start:
                stop-=step
                list.append(stop)
            list.remove(-1)
            return list
        a=unrange(stop,start,step)
        np.savetxt(path,a,fmt=numbertipe,delimiter='/n')
    elif stop>start:
        a=range(stop,start,step)
        np.savetxt(path,a,fmt=numbertipe,delimiter='/n')
    else:
        print("Stop can not be the same as start.")
